@@ -1,11 +1,11 @@
-#' allGens
+#' calcAllGens
 #' A function to calculate the number of individuals in each generation. This is a supporting function for \code{simulatePedigree}.
 #' @param kpc Number of kids per couple (integer >= 2).
 #' @param Ngen Number of generations (integer >= 1).
 #' @param marR Mating rate (numeric value ranging from 0 to 1).
 #' @return Returns a vector containing the number of individuals in every generation.
 #' @export
-allGens <- function(kpc, Ngen, marR) {
+calcAllGens <- function(kpc, Ngen, marR) {
   # Check if the number of generations is valid
   if (Ngen < 1) {
     stop("The number of generations should be an integer greater or equal than 1")
@@ -23,14 +23,15 @@ allGens <- function(kpc, Ngen, marR) {
   }
   return(allGens)
 }
+#' @rdname calcAllGens
+allGens <- calcAllGens
 
-
-#' sizeAllGens
+#' calcFamilySizeByGen
 #' An internal supporting function for \code{simulatePedigree}.
-#' @inheritParams allGens
+#' @inheritParams calcAllGens
 #' @return Returns a vector including the number of individuals in every generation.
 
-sizeAllGens <- function(kpc, Ngen, marR) {
+calcFamilySizeByGen <- function(kpc, Ngen, marR) {
   Nmid <- Ngen - 2
   midGens <- numeric(length = Nmid)
 
@@ -43,17 +44,18 @@ sizeAllGens <- function(kpc, Ngen, marR) {
   # Calculate the number of individuals for the last generation
   lastGen <- ceiling(kpc^(Ngen - 1) * marR^(Ngen - 2))
   allGens <- c(2, midGens, lastGen)
-  # print(allGens)
+  # message(allGens)
   return(allGens)
 }
+#' @rdname calcFamilySizeByGen
+sizeAllGens <- calcFamilySizeByGen
 
-
-#' famSizeCal
+#' calcFamilySize
 #' A function to calculate the total number of individuals in a pedigree given parameters. This is a supporting function for function \code{simulatePedigree}
-#' @inheritParams allGens
+#' @inheritParams calcAllGens
 #' @return Returns a numeric value indicating the total pedigree size.
 #' @export
-famSizeCal <- function(kpc, Ngen, marR) {
+calcFamilySize <- function(kpc, Ngen, marR) {
   if (Ngen < 1) {
     stop("The number of generations should be an integer greater than or equal to 1")
   } else if (Ngen == 1) {
@@ -71,3 +73,7 @@ famSizeCal <- function(kpc, Ngen, marR) {
   }
   return(size)
 }
+
+#' @rdname calcFamilySize
+#'
+famSizeCal <- calcFamilySize
