@@ -22,7 +22,7 @@ checkIDs <- function(ped, verbose = FALSE, repair = FALSE) {
   # Initialize a list to store validation results
   validation_results <- list()
 
-  if (verbose) {
+  if (verbose == TRUE) {
     cat("Checking IDs...\n")
     cat("Step 1: Checking for unique IDs...\n")
   }
@@ -30,26 +30,26 @@ checkIDs <- function(ped, verbose = FALSE, repair = FALSE) {
   # Identify non-unique IDs
   id_check <- checkIDuniqueness(ped = ped, verbose = verbose)
 
-  if (verbose) {
+  if (verbose == TRUE) {
     cat("Step 2: Checking for within row duplicats...\n")
   }
   row_check <- checkWithinRowDuplicates(ped = ped, verbose = verbose)
 
   validation_results <- c(id_check, row_check)
 
-  if (verbose) {
+  if (verbose == TRUE) {
     cat("Validation Results:\n")
     message(validation_results)
   }
   if (repair) {
-    if (verbose) {
+    if (verbose == TRUE) {
       cat("Attempting to repair:\n")
       cat("Step 1: Attempting to repair non-unique IDs...\n")
     }
 
     # Initialize a list to track changes made during repair
     changes <- list()
-    if (verbose) {
+    if (verbose == TRUE) {
       cat("Is the row a between-person duplicate?\n")
     }
     repaired_ped <- ped
@@ -70,11 +70,11 @@ checkIDs <- function(ped, verbose = FALSE, repair = FALSE) {
         }
       }
     }
-    if (verbose) {
+    if (verbose == TRUE) {
       cat("Step 2: No repair for parents who are their children at this time\n")
     }
 
-    if (verbose) {
+    if (verbose == TRUE) {
       cat("Changes Made:\n")
       message(changes)
     }
@@ -106,7 +106,7 @@ checkIDuniqueness <- function(ped, verbose = FALSE) {
 
   duplicated_ids <- ped$ID[duplicated(ped$ID) | duplicated(ped$ID, fromLast = TRUE)]
 
-  if (verbose) {
+  if (verbose == TRUE) {
     if (length(duplicated_ids) > 0) {
       cat(length(duplicated_ids), " non-unique IDs found.\n")
     } else {
@@ -145,7 +145,7 @@ checkWithinRowDuplicates <- function(ped, verbose = FALSE) {
   # get the total number of within row duplicates
   total <- length(is_own_father) + length(is_own_mother) + length(duplicated_parents)
 
-  if (verbose) {
+  if (verbose == TRUE) {
     if (total > 0) {
       cat(total, " within row duplicates found.\n")
       if (length(is_own_father) > 0) cat(length(is_own_father), " individuals are their own fathers.\n")
