@@ -59,12 +59,12 @@
                                ...) {
   # Checks
   if (!file.exists(file_path)) stop("File does not exist: ", file_path)
-  if (verbose) {
+  if (verbose == TRUE) {
     message(paste("Reading file:", file_path))
   }
   file <- data.frame(X1 = readLines(file_path))
   file_length <- nrow(file)
-  if (verbose) {
+  if (verbose == TRUE) {
     message(paste0("File is ", file_length, " lines long"))
   }
 
@@ -106,7 +106,7 @@
   df_temp <- as.data.frame(matrix(nrow = 1, ncol = length(all_var_names)))
   names(df_temp) <- all_var_names
 
-  if (verbose) {
+  if (verbose == TRUE) {
     message("Parsing GEDCOM file")
   }
   for (i in 1:length(file[1][[1]])) {
@@ -291,7 +291,7 @@
   df_temp <- rbind(df_temp, line_to_write)
   df_temp <- df_temp[!is.na(df_temp$id), ]
 
-  if (verbose) {
+  if (verbose == TRUE) {
     message(paste0("File has ", nrow(df_temp), " people"))
   }
   if (nrow(df_temp) == 0) {
@@ -303,7 +303,7 @@
   }
 
   if (post_process) {
-    if (verbose) {
+    if (verbose == TRUE) {
       message("Post-processing data frame")
     }
     # Remove the first row (empty)
@@ -334,7 +334,7 @@
                                       verbose = FALSE) {
   # Add mom and dad ids
   if (add_parents) {
-    if (verbose) {
+    if (verbose == TRUE) {
       message("Processing parents")
     }
     df_temp <- .processParents.legacy(df_temp, datasource = "gedcom")
@@ -346,13 +346,13 @@
 
   if (remove_empty_cols) {
     # Remove empty columns
-    if (verbose) {
+    if (verbose == TRUE) {
       message("Removing empty columns")
     }
     df_temp <- df_temp[, colSums(is.na(df_temp)) < nrow(df_temp)]
   }
   if (skinny) {
-    if (verbose) {
+    if (verbose == TRUE) {
       message("Slimming down the data frame")
     }
     df_temp <- df_temp[, colSums(is.na(df_temp)) < nrow(df_temp)]
@@ -594,7 +594,7 @@
 #' @param df_temp A data frame containing the columns to be combined.
 #' @keywords internal
 .collapseNames.legacy <- function(verbose, df_temp) {
-  if (verbose) {
+  if (verbose == TRUE) {
     message("Combining Duplicate Columns")
   }
   # need to check if any values aren't NA in name_given_pieces and name_surn_pieces
