@@ -24,7 +24,7 @@ makeTwins <- function(ped, ID_twin1 = NA_integer_,
     "dadID", "momID", "spID", "sex"
   ), collapse = "")) {
     ped <- standardizeColnames(ped, verbose = verbose)
-    if (verbose) {
+    if (verbose == TRUE) {
       cat("The input pedigree is not in the same format as the output of simulatePedigree\n")
     }
     # stop("The input pedigree is not in the same format as the output of simulatePedigree")
@@ -116,7 +116,7 @@ makeTwins <- function(ped, ID_twin1 = NA_integer_,
     ped$MZtwin[ped$ID == ID_twin1] <- ID_twin2
     ped$MZtwin[ped$ID == ID_twin2] <- ID_twin1
   }
-  if (verbose) {
+  if (verbose == TRUE) {
     cat("twin1", ID_twin1, "\n")
     cat("twin2", ID_twin2, "\n")
   }
@@ -160,7 +160,7 @@ makeInbreeding <- function(ped,
     collapse = ""
   )) {
     ped <- standardizeColnames(ped, verbose = verbose)
-    if (verbose) {
+    if (verbose == TRUE) {
       cat("The input pedigree is not in the same format as the output of simulatePedigree\n")
     }
   }
@@ -290,29 +290,65 @@ dropLink <- function(ped,
   }
   return(ped)
 }
+
 #' addPersonToTree
 #' A function to add a new person to an existing pedigree \code{data.frame}.
 #' @param ped A \code{data.frame} representing the existing pedigree.
-#' @param name Optional. A character string representing the name of the new person. If not provided, the name will be set to \code{NA}.
+#' @param name Optional. A character string representing the name of the new
+#' person. If not provided, the name will be set to \code{NA}.
 #' @param sex A value representing the sex of the new person.
-#' @param momID Optional. The ID of the mother of the new person. If not provided, it will be set to \code{NA}.
-#' @param dadID Optional. The ID of the father of the new person. If not provided, it will be set to \code{NA}.
-#' @param twinID Optional. The ID of the twin of the new person. If not provided, it will be set to \code{NA}.
-#' @param zygosity Optional. A character string indicating the zygosity of the new person. If not provided, it will be set to \code{NA}.
-#' @param personID Optional. The ID of the new person. If not provided, it will be generated as the maximum existing personID + 1.
+#' @param momID Optional. The ID of the mother of the new person. If not
+#' provided, it will be set to \code{NA}.
+#' @param dadID Optional. The ID of the father of the new person. If not
+#' provided, it will be set to \code{NA}.
+#' @param twinID Optional. The ID of the twin of the new person. If not
+#' provided, it will be set to \code{NA}.
+#' @param zygosity Optional. A character string indicating the zygosity of the
+#' new person. If not provided, it will be set to \code{NA}.
+#' @param personID Optional. The ID of the new person. If not provided, it will
+#' be generated as the maximum existing personID + 1.
+#' @param notes Optional. A character string for notes about the new person. If
+#' not provided, it will be set to \code{NA}.
+#' @param url Optional. A URL column for the new person. If not provided, it
+#' will be set to \code{NA}.
+#' @param overwrite Logical. If \code{TRUE}, the function will overwrite an
+#' existing person with the same \code{personID}. If \code{FALSE}, it will stop
+#' if a person with the same
+#' \code{personID} already exists.
 #'
 #' @return A \code{data.frame} with the new person added to the existing pedigree.
 #'
 #' @export
-addPersonToPed <- function(ped, name = NULL, sex = NULL, momID = NA, dadID = NA, twinID = NULL, personID = NULL, zygosity = NULL) {
+addPersonToPed <- function(ped, name = NULL,
+                           sex = NULL, momID = NA,
+                           dadID = NA, twinID = NULL,
+                           personID = NULL, zygosity = NULL,
+                           notes = NULL, url = NULL,
+                           overwrite = FALSE) {
   stopifnot(is.data.frame(ped))
+  if (overwrite == TRUE) {
+    # Check if the personID already exists in the pedigree
+    # Copy structure from an existing row
 
-  # Copy structure from an existing row
-  new_row <- ped[1, , drop = FALSE]
+    new_row <- ped[ped$personID == personID, ]
+    # drop the row with the personID
+    if (nrow(new_row) == 0) {
+      stop("The personID does not exist in the pedigree. Set overwrite=FALSE to add a new person with a new ID.")
+    }
+    # Remove the row with the personID
+    # ped <-  ped[ped$personID!=personID, ]
+  } else {
+    # Check if the personID already exists in the pedigree
+    if (!is.null(personID) && personID %in% ped$personID) {
+      stop("The personID already exists in the pedigree. Set overwrite=TRUE to overwrite the existing person.")
+    }
 
-  # Blank out all values
-  new_row[1, ] <- NA
+    # Copy structure from an existing row
+    new_row <- ped[1, , drop = FALSE]
 
+    # Blank out all values
+    new_row[1, ] <- NA
+  }
   # Assign new values
   if (!is.null(personID)) {
     new_row$personID <- personID
@@ -350,7 +386,22 @@ addPersonToPed <- function(ped, name = NULL, sex = NULL, momID = NA, dadID = NA,
   } else if ("zygosity" %in% colnames(ped)) {
     new_row$zygosity <- NA_character_
   }
-
+  if (!is.null(notes) && "notes" %in% colnames(ped)) {
+    new_row$notes <- notes
+  } else if ("notes" %in% colnames(ped)) {
+    new_row$notes <- NA_character_
+  }
+  if (!is.null(url) && "url" %in% colnames(ped)) {
+    new_row$url <- url
+  } else if ("url" %in% colnames(ped)) {
+    new_row$url <- NA_character_
+  }
   # Append to data frame
-  rbind(ped, new_row)
+  if (overwrite == TRUE) {
+    ped[ped$personID == personID, ] <- new_row
+
+    return(ped)
+  } else {
+    return(rbind(ped, new_row))
+  }
 }
