@@ -25,7 +25,7 @@ test_that("com2links produces correct output with a single relationship matrix (
 })
 
 test_that("com2links produces correct output with cn_ped_matrix", {
-  data(ASOIAF)
+  data(ASOIAF, package = "ggpedigree")
   cn_ped_matrix <- ped2cn(ASOIAF, sparse = TRUE)
 
   result <- com2links(cn_ped_matrix = cn_ped_matrix, writetodisk = FALSE)
